==> apache-ranger-1.1.0.tar.gz: apache-ranger-1.1.0/agents-audit/src/main/java/org/apache/ranger/audit/provider/StandAloneAuditProviderFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ranger.audit.provider;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class StandAloneAuditProviderFactory extends AuditProviderFactory {
	private static final Log LOG = LogFactory.getLog(StandAloneAuditProviderFactory.class);

	private volatile static StandAloneAuditProviderFactory sFactory = null;

	public static StandAloneAuditProviderFactory getInstance() {
		StandAloneAuditProviderFactory ret = sFactory;
		if(ret == null) {
			synchronized(StandAloneAuditProviderFactory.class) {
				ret = sFactory;
				if(ret == null) {
					ret = sFactory = new StandAloneAuditProviderFactory();
				}
			}
		}
		return ret;
	}

	private StandAloneAuditProviderFactory() {
		super();
		LOG.info("StandAloneAuditProviderFactory: created..");
	}
}

==> apache-ranger-2.5.0.tar.gz: apache-ranger-2.5.0/agents-audit/src/main/java/org/apache/ranger/audit/provider/StandAloneAuditProviderFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ranger.audit.provider;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class StandAloneAuditProviderFactory extends AuditProviderFactory {
	private static final Logger LOG = LoggerFactory.getLogger(StandAloneAuditProviderFactory.class);

	private volatile static StandAloneAuditProviderFactory sFactory = null;

	public static StandAloneAuditProviderFactory getInstance() {
		StandAloneAuditProviderFactory ret = sFactory;
		if(ret == null) {
			synchronized(StandAloneAuditProviderFactory.class) {
				ret = sFactory;
				if(ret == null) {
					ret = sFactory = new StandAloneAuditProviderFactory();
				}
			}
		}
		return ret;
	}

	private StandAloneAuditProviderFactory() {
		super();
		LOG.info("StandAloneAuditProviderFactory: created..");
	}
}
